pub struct WasmStatefulHandlerV2 { /* private fields */ }Expand description
Sandboxed ABI v2 handler. The linker provides no WASI interfaces, so the guest has no filesystem, network, environment, process, stdio, clock or random imports.
Implementations
Sourceimpl WasmStatefulHandlerV2
impl WasmStatefulHandlerV2
Sourcepub fn new(
component_bytes: &[u8],
expected_metadata: StatefulHandlerMetadataV2,
model_json: &Value,
) -> Result<Self, StatefulHandlerErrorV2>
pub fn new( component_bytes: &[u8], expected_metadata: StatefulHandlerMetadataV2, model_json: &Value, ) -> Result<Self, StatefulHandlerErrorV2>
Compile and configure a component whose bytes were already authenticated
by the caller. Guest metadata must exactly match expected_metadata.